@@ -48,6 +48,7 @@ public:
     void updatePixmap(QPixmap *pMap);
     void updateModulesActions(const QList<QAction *> &list);
     void updateModulesMenus(const QList<QMenu *> &list);
+    QScreen* selectedScreen() const;
 
 public Q_SLOTS:
     void showWindow(const QString& str);
@@ -58,7 +59,8 @@ public Q_SLOTS:
 protected:
     void closeEvent(QCloseEvent *e);
     void changeEvent(QEvent *e);
-    void resizeEvent(QResizeEvent *event); // event resuze window
+    void resizeEvent(QResizeEvent *event);
+    void showEvent(QShowEvent *event);
     bool eventFilter(QObject *obj, QEvent *event);
 
 private:
@@ -71,11 +73,9 @@ private:
     QAction *actCopy;
     QAction *actOptions;
     QAction *actAbout;
-    QAction *actHelp;
     QAction *actQuit;
     Config *_conf;
     QMenu *_trayMenu;
-    QShortcut *_hideWnd;
     bool _trayed;
     QIcon appIcon;
 
@@ -84,10 +84,10 @@ private:
     void killTray();
     void disableTrayMenuActions(bool disable);
     void updateShortcuts();
+    void fitPixmap();
 
 private Q_SLOTS:
     void saveScreen();
-    void showHelp();
     void showOptions();
     void showAbout();
     void delayBoxChange(int);
